#
# spec file for package ghc-path-io
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name path-io
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.4.2
Release:        lp151.1.2
Summary:        Interface to ‘directory’ package for users of ‘path’
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-dlist-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-path-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-compat-devel
%if %{with tests}
BuildRequires:  ghc-hspec-devel
%endif

%description
Interface to ‘directory’ package for users of ‘path’.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE.md

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Thu Feb 14 2019 psimons@suse.com
- Update path-io to version 1.4.2.
  [#]# Path IO 1.4.2
  * Fixed various bugs in `listDirRecurRel`, `walkDirRel`, and
    `walkDirAccumRel` and clarified their behavior in the docs.
* Sat Jan 19 2019 Peter Simons <psimons@suse.com>
- Update Cabal build instructions for more accurate dependencies.
* Fri Dec 21 2018 psimons@suse.com
- Update path-io to version 1.4.1.
  [#]# Path IO 1.4.1
  * Fixed a bug in `walkDirRel` that resulted in `NotAProperPrefix` exception
    every time the function was called.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Sun Jul 29 2018 psimons@suse.com
- Update path-io to version 1.4.0.
  [#]# Path IO 1.4.0
  * Added relative versions of some actions: `listDirRel`, `listDirRecurRel`,
    `walkDirRel`, and `walkDirAccumRel`.
  * Dropped support for GHC 7.8.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update path-io to version 1.3.3 revision 3.
  * (Hopefully) fixed test suite failure with Cabal 2.0 and GHC 8.2.1.
  * Reduce a number of `(MonadIO m, MonadThrow m)` constraints to just
    `MonadIO m` [#27](https://github.com/mrkkrp/path-io/issues/27)
  * Made `listDirRecur` faster for deep directory trees.
  * Change the default behavior of recursive traversal APIs to not follow
    symbolic links. The change affects the following functions:
    `listDirRecur`, `copyDirRecur`, and `copyDirRecur'`.
  * Add `isSymlink` which allows to test whether a path is a symbolic link.
  * Move the type functions `AbsPath` and `RelPath` to the `AnyPath` type
    class (previously they were standalone closed type families, now they are
    associated types of `AnyPath`).
  * Improved the documentation and metadata.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Fri May  5 2017 psimons@suse.com
- Update to version 1.2.2 revision 1 with cabal2obs.
* Sun Jan  8 2017 psimons@suse.com
- Update to version 1.2.2 with cabal2obs.
* Wed Jan  4 2017 psimons@suse.com
- Update to version 1.2.0 revision 1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 1.2.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.1.0 revision 0 with cabal2obs.
* Tue Mar  8 2016 mimi.vx@gmail.com
- package ghc-path-io updated by st2obs
* Sat Feb 13 2016 mimi.vx@gmail.com
- ghc-path-io generated by st2obs scritpt
